The functions listed below are deprecated and will be defunct
in the near future. When possible, functions with similar functionality are mentioned.
Help pages for deprecated functions are available at help-("deprecated").
area.simulation.plot(x, response = "levels", bw = FALSE)spike.simulation.plot(x, response = "levels", bw = FALSE)
a dynardl model with a simulation to be plotted
whether the plot of the response should be shown in levels of the dependent variable (levels)
or in changes from the mean of the dependent variable (mean.changes). The default is levels
should the colors be in black and white (for publication)? The default is FALSE
a dynardl model with a simulation to be plotted
whether the plot of the response should be shown in levels of the dependent variable (levels)
or in changes from the mean of the dependent variable (mean.changes). The default is levels
should the colors be in black and white (for publication)? The default is FALSE
an area plot
a spike plot
For area.simulation.plot, use dynardl.simulation.plot.
For spike.simulation.plot, use dynardl.simulation.plot.
link{dynamac-deprecated}
link{dynamac-deprecated}